@@ -1,7 +1,7 @@
 /*
  * MessagePack for Ruby
  *
- * Copyright (C) 2008-2012 FURUHASHI Sadayuki
+ * Copyright (C) 2008-2013 Sadayuki Furuhashi
  *
  *    Licensed under the Apache License, Version 2.0 (the "License");
  *    you may not use this file except in compliance with the License.
@@ -165,6 +165,8 @@ size_t msgpack_buffer_read_to_string_nonblock(msgpack_buffer_t* b, VALUE string,
 #else
         rb_str_replace(string, s);
 #endif
+        /* here doesn't have to call ENCODING_SET because
+         * encoding of s is always ASCII-8BIT */
         _msgpack_buffer_consumed(b, length);
         return length;
     }
@@ -307,8 +309,8 @@ static inline void _msgpack_buffer_append_reference(msgpack_buffer_t* b, VALUE s
 
     _msgpack_buffer_add_new_chunk(b);
 
-    char* data = RSTRING_PTR(string);
-    size_t length = RSTRING_LEN(string);
+    char* data = RSTRING_PTR(mapped_string);
+    size_t length = RSTRING_LEN(mapped_string);
 
     b->tail.first = (char*) data;
     b->tail.last = (char*) data + length;
